@@ -21,7 +21,7 @@ extends 'HPC::Runner::Scheduler';
 #extends 'HPC::Runner::Slurm';
 with 'MooseX::SimpleConfig';
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 # For pretty man pages!
 $ENV{TERM}='xterm-256color';
@@ -157,22 +157,10 @@ Calling system module load * does not work within a screen session!
 
 =cut
 
-sub run {
+sub BUILD {
     my $self = shift;
-
-    $DB::single=2;
-
     $self->logname('pbs_logs');
     $self->log($self->init_log);
-    $DB::single=2;
-
-    if($self->serial){
-        $self->procs(1);
-    }
-
-    $self->check_files;
-    $self->parse_file_slurm;
-    $DB::single=2;
 }
 
 sub get_nodes {
